"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.storeFilePathsInFolders = exports.getFilePathsInFolder = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const storage_1 = require("./storage");
const utilities_1 = require("./utilities");
function getFilePathsInFolder(folderPath, deepSearch) {
    if (!(0, fs_1.statSync)(folderPath).isDirectory()) {
        throw new Error("Folder path is invalid: " + folderPath);
    }
    const allFiles = [];
    for (const name of (0, fs_1.readdirSync)(folderPath)) {
        const fullPath = folderPath + path_1.sep + name;
        if (name.includes(".") && (0, fs_1.statSync)(fullPath).isFile()) {
            allFiles.push(fullPath);
        }
        else if (deepSearch && (0, fs_1.statSync)(fullPath).isDirectory()) {
            allFiles.push(...getFilePathsInFolder(fullPath, deepSearch));
        }
    }
    return allFiles;
}
exports.getFilePathsInFolder = getFilePathsInFolder;
async function storeFilePathsInFolders(folderPaths, deepSearch) {
    if (!folderPaths) {
        folderPaths = await (0, utilities_1.workspaceFolders)();
    }
    const filePaths = folderPaths.flatMap((path) => getFilePathsInFolder(path, deepSearch));
    (0, storage_1.saveFilePaths)(filePaths);
}
exports.storeFilePathsInFolders = storeFilePathsInFolders;
